@@ -3,21 +3,31 @@
 #' Assigns a label to a vector or data frame, or returns value stored 
 #' in the object's \code{label} attribute (or \code{NA} if none exists).
 #' 
-#' @aliases label label<-
-#' @usage label(x, all = FALSE, fallback = FALSE, simplify = FALSE)
+#' @aliases label label<- llabel
+#' @usage 
+#' label(x, all = FALSE, fallback = FALSE, simplify = FALSE)
 #' label(x) <- value
+#' llabel(x, all = TRUE, fallback = FALSE, simplify = FALSE)
 #' 
 #' @param x An R object to extract labels from.
 #' @param all Logical. When x is a data frame, setting this argument to
-#'   \code{TRUE} will make the function return all variable labels. By default,
-#'   its value is \code{FALSE}, so that if x is a data frame, it is the data
-#'   frame's label that will be returned.
-#' @param fallback a logical value indicating if labels should fallback to
-#'   object name(s). Defaults to \code{FALSE}.
-#' @param simplify When x is a data frame and \code{all = TRUE}, coerce results
-#'   to a vector and remove \code{NA}'s. Default is \code{FALSE}.
-#' @param value String to be used as label. To clear existing labels, use \code{NA}
-#'   or \code{NULL}.
+#'   \code{TRUE} will make the function return all variable labels. By 
+#'   default, its value is \code{FALSE}, so that if x is a data frame, it is
+#'   the data frame's label itself that will be returned.
+#' @param fallback a logical value indicating if labels (returned values) 
+#'   should fallback to object name(s). Defaults to \code{FALSE}.
+#' @param simplify When x is a data frame and \code{all = TRUE}, coerce 
+#'   results to a vector and remove \code{NA}'s. Default is \code{FALSE}.
+#' @param value String to be used as label. To clear existing labels, use
+#'   \code{NA} or \code{NULL}.
+#' 
+#' @returns A single character vector if \code{all = FALSE} (default),
+#'   or a named list if \code{all = TRUE} (named vector when using
+#'   \code{simplify = TRUE}.
+#' 
+#' @details
+#'  The wrapper function \code{llabel} was named that way to avoid conflicting
+#'  with base function \code{\link[base]{labels}}.
 #' 
 #' @author
 #' Dominic Comtois, \email{dominic.comtois@@gmail.com},
@@ -112,10 +122,18 @@ label <- function(x, all = FALSE, fallback = FALSE, simplify = FALSE) {
   return(x)
 }
 
+#' @usage 
+#' llabel(x, all = TRUE, fallback = FALSE, simplify = FALSE)
+#' @export
+llabel <- function(x, all = TRUE, fallback = FALSE, simplify = FALSE) {
+  label(x, all = all, fallback = fallback, simplify = simplify)
+} 
+
 #' Clear Variable and Data Frame Label(s)
 #'
-#' Returns the object with all labels removed. Both the \dQuote{label} attribute
-#' and \pkg{Hmisc}'s \dQuote{labelled} class are removed.
+#' Returns the object with all labels removed. The \dQuote{label} attribute
+#' as well as the \dQuote{labelled} class (used by Hmisc and labelled) are
+#' cleared.
 #'
 #' @usage unlabel(x)
 #' @param x An R object to remove labels from.
